# Copyright 2017 Hynek Schlawack

# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

#     http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
Exceptions raised by *environ-config*.
"""

from __future__ import absolute_import, division, print_function


class ConfigError(Exception):
    pass


class MissingEnvValueError(ConfigError):
    """
    A mandatory environment variable can't be found.
    """


class MissingSecretError(ConfigError):
    """
    A mandatory secret can't be found.
    """


class MissingSecretImplementationError(Exception):
    """
    A secret implementation could not be loaded
    """
